salesforce-streaming-client
==========================

A Salesforce streaming API client for python, built on salesforce-requests-oauthlib and python-bayeux.


Tests
-----

To run tests, install py.test and pytest-cov in your virtualenv and

$ py.test --cov=src/salesforce_streaming_client/ --cov-report html:coverage

View test coverage results at ``./coverage``.

Credits
-------

- `Distribute`_
- `modern-package-template`_
- `py.test`_
- `pytest-cov`_

.. _Distribute: http://pypi.python.org/pypi/distribute
.. _`modern-package-template`: http://pypi.python.org/pypi/modern-package-template
.. _`py.test`: http://doc.pytest.org/en/latest/index.html
.. _`pytest-cov`: https://pypi.python.org/pypi/pytest-cov
